function EasyCanvas(option) {
    this.canvas = option.canvas
    this.context = this.canvas.getContext("2d")
    this.ratio = this.getPixelRatio()
    this.originSize = {}

    if (option.maxWidth != undefined && option.maxWidth > 0) {
        this.maxWidth = option.maxWidth
    } else if (option.maxHeight != undefined && option.maxHeight > 0) {
        this.maxHeight = option.maxHeight
    }
}

EasyCanvas.prototype.setMaxWidth = function(width) {
    if (width != undefined) {
        this.maxWidth = width
        this.maxHeight = undefined
        this.onSizeChange()
    }
}

EasyCanvas.prototype.setMaxHeight = function(height) {
    if (height != undefined) {
        this.maxHeight = height
        this.maxWidth = undefined
        this.onSizeChange()
    }
}

EasyCanvas.prototype.getPixelRatio = function() {
    let backingStore = this.context.backingStorePixelRatio ||
        this.context.webkitBackingStorePixelRatio ||
        this.context.mozBackingStorePixelRatio ||
        this.context.msBackingStorePixelRatio ||
        this.context.oBackingStorePixelRatio ||
        this.context.backingStorePixelRatio || 1;
    return (window.devicePixelRatio || 1) / backingStore;
}

EasyCanvas.prototype.clear = function() {
    this.context.clearRect(0, 0, this.canvas.width, this.canvas.heigth)
}

EasyCanvas.prototype.resize = function(width, height) {
    this.originSize = {
        width: width || 0,
        height: height || 0
    }
    this.canvas.width = this.originSize.width * this.ratio
    this.canvas.height = this.originSize.height * this.ratio
    this.context.scale(this.ratio, this.ratio)
    this.clear()
    this.onSizeChange()
}

EasyCanvas.prototype.onSizeChange = function() {
    let width, height
    if (this.originSize.width == 0 || this.originSize.height == 0) {
        width = 0
        height = 0
    } else if (this.maxWidth != undefined) {
        width = Math.min(this.originSize.width, this.maxWidth)
        height = width * this.originSize.heigth / this.originSize.width
    } else if (this.maxHeigth != undefined) {
        height = Math.min(this.originSize.height, this.maxHeight)
        width = width * this.originSize.heigth / this.originSize.width
    } else {
        width = this.originSize.width
        height = this.originSize.height
    }
    this.canvas.style.width = width + 'px'
    this.canvas.style.height = height + 'px'
}

EasyCanvas.prototype.drawImages = function(images, configs) {
    let indexSet = {}
    if (configs == undefined || configs.length == 0) {
        //不指定拼接配置时，默认按顺序显示所有图片
        configs = []
        for (let i = 0; i < images.length; i++) {
            configs.push({
                i: i + 1,
                x: 0,
                y: 0,
                w: 0,
                h: 0
            })
            indexSet[i] = true
        }
    } else {
        for (let i = 0; i < configs.length; i++) {
            indexSet[configs[i].i - 1] = true;
        }
    }
    let maxWidth = 0;
    let totalHeight = 0;
    for (let i = 0; i < configs.length; i++) {
        //计算最大宽度与合计高度
        if (configs[i].w <= 0) {
            configs[i].w = images[configs[i].i - 1].width;
        }
        if (configs[i].h <= 0) {
            configs[i].h = images[configs[i].i - 1].height;
        }
        maxWidth = Math.max(maxWidth, configs[i].w);
        totalHeight += configs[i].h;
    }
    if (maxWidth > 0 && totalHeight > 0) {
        //设置画布大小
        this.resize(maxWidth, totalHeight)
        //绘画到画布
        let height = 0;
        for (let i = 0; i < configs.length; i++) {
            this.context.drawImage(images[configs[i].i - 1], configs[i].x, configs[i].y, configs[i].w, configs[i].h, 0, height, configs[i].w, configs[i].h);
            height += configs[i].h;
        }
    } else {
        this.resize()
    }
}